@@ -19,6 +19,10 @@
 //!   of time so you can migrate.
 //! - Migrating will often be as easy as dropping the `_lab` suffix from imports when migrating.
 
+#![deny(rust_2018_idioms, nonstandard_style)]
+#![warn(future_incompatible, missing_docs)]
+#![cfg_attr(docsrs, feature(doc_cfg))]
+
 mod acceptable;
 mod body_extractor_fold;
 mod body_hash;
@@ -28,6 +32,7 @@ mod channel_body;
 mod csv;
 mod display_stream;
 mod err_handler;
+mod hsts;
 mod html;
 mod json;
 mod lazy_data;
@@ -45,6 +50,7 @@ mod utils;
 pub mod body;
 pub mod extract;
 pub mod guard;
+pub mod header;
 pub mod middleware;
 pub mod respond;
 pub mod web;
